@@ -1,7 +1,7 @@
 #! /bin/sh
 
-cp ../dylib_for_xcode/MediaInfoLib/libmediainfo.dylib MediaInfo/Source/GUI/Cocoa ;
-cd MediaInfo/Source/GUI/Cocoa ;
+lipo -thin "x86_64" ../dylib_for_xcode/MediaInfoLib/libmediainfo.dylib -o MediaInfo/Source/GUI/Cocoa/libmediainfo.dylib
+cd MediaInfo/Source/GUI/Cocoa
 install_name_tool -id @executable_path/../Resources/libmediainfo.dylib libmediainfo.dylib ;
 
 cd _i18n
