@@ -11,6 +11,7 @@
 //---------------------------------------------------------------------------
 
 //---------------------------------------------------------------------------
+#include "Common/Core.h"
 #include "Help.h"
 #include "Config.h"
 //---------------------------------------------------------------------------
@@ -18,11 +19,24 @@
 //***************************************************************************
 //
 //***************************************************************************
+//---------------------------------------------------------------------------
+String Program_Name = __T("MediaInfo");
+
+void Set_Program_Name(const String &Name)
+{
+    Program_Name = Name;
+    #if defined(_MSC_VER)
+        Program_Name = Program_Name.substr(Program_Name.rfind('\\')+1);
+        Program_Name = Program_Name.substr(0, Program_Name.find('.'));
+    #else
+        Program_Name = Program_Name.substr(Program_Name.rfind('/')+1);
+    #endif
+}
 
 //---------------------------------------------------------------------------
 int Help()
 {
-    TEXTOUT("Usage: \"MediaInfo [-Options...] FileName1 [Filename2...]\"");
+    STRINGOUT(String(__T("Usage: \" [-Options...] FileName1 [Filename2...]\"")).insert(8, Program_Name));
     TEXTOUT("");
     TEXTOUT("Options:");
     TEXTOUT("--Help, -h");
@@ -34,20 +48,35 @@ int Help()
     TEXTOUT("--Version");
     TEXTOUT("                    Display MediaInfo version and exit");
     TEXTOUT("");
-    TEXTOUT("--Full , -f");
+    TEXTOUT("--Full, -f");
     TEXTOUT("                    Full information Display (all internal tags)");
     TEXTOUT("--Output=HTML");
     TEXTOUT("                    Full information Display with HTML tags");
     TEXTOUT("--Output=XML");
     TEXTOUT("                    Full information Display with XML tags");
+    TEXTOUT("--Output=OLDXML");
+    TEXTOUT("                    Full information Display with XML tags using the older");
+    TEXTOUT("                    MediaInfo schema");
+    TEXTOUT("--Output=JSON");
+    TEXTOUT("                    Full information Display using JSON");    
     TEXTOUT("--Output=EBUCore");
     TEXTOUT("                    Full information Display with EBUCore compliant XML tags");
+    TEXTOUT("--Output=EBUCore_JSON");
+    TEXTOUT("                    Full information Display with EBUCore 1.8 compliant JSON");
     TEXTOUT("--Output=PBCore");
     TEXTOUT("                    Full information Display with PBCore compliant XML tags");
     TEXTOUT("--Output=PBCore2");
     TEXTOUT("                    Full information Display with PBCore 2.0 compliant XML tags");
-    TEXTOUT("--Output=...y");
-    TEXTOUT("                    Template defined information Display");
+    TEXTOUT("--AcquisitionDataOutputMode=segmentParameter");
+    TEXTOUT("                    Display Acquisition Data by segment then parameter (EBUCore");
+    TEXTOUT("                    and NISO Z39.87 outputs)");
+    TEXTOUT("--AcquisitionDataOutputMode=parameterSegment");
+    TEXTOUT("                    Display Acquisition Data by parameter then segment (EBUCore");
+    TEXTOUT("                    and NISO Z39.87 outputs)");
+    TEXTOUT("--ExternalMetadata=...");
+    TEXTOUT("                    Add external metadata to the output (EBUCore output)");
+    TEXTOUT("--ExternalMetadataConfig=...");
+    TEXTOUT("                    Output template for external metadata (EBUCore output)");
     TEXTOUT("--Info-Parameters");
     TEXTOUT("                    Display list of Inform= parameters");
     TEXTOUT("");
@@ -122,8 +151,8 @@ int Help()
 //---------------------------------------------------------------------------
 int Help_Nothing()
 {
-    TEXTOUT("Usage: \"MediaInfo [-Options...] FileName1 [Filename2...]\"");
-    TEXTOUT("\"MediaInfo --Help\" for displaying more information");
+    STRINGOUT(String(__T("Usage: \" [-Options...] FileName1 [Filename2...]\"")).insert(8, Program_Name));
+    STRINGOUT(String(__T("\" --Help\" for displaying more information")).insert(1, Program_Name));
 
     return MI_OK;
 }
@@ -132,7 +161,7 @@ int Help_Nothing()
 int Help_Output()
 {
     TEXTOUT("--Output=...  Specify a template (BETA)");
-    TEXTOUT("Usage: \"MediaInfo --Output=[xxx;]Text FileName\"");
+    STRINGOUT(String(__T("Usage: \" --Output=[xxx;]Text FileName\"")).insert(8, Program_Name));
     TEXTOUT("");
     TEXTOUT("xxx can be: General, Video, Audio, Text, Chapter, Image, Menu");
     TEXTOUT("Text can be the template text, or a filename");
@@ -141,13 +170,13 @@ int Help_Output()
     TEXTOUT("See --Info-Parameters for available parameters in the text");
     TEXTOUT("(Parameters must be surrounded by \"%\" sign)");
     TEXTOUT("");
-    TEXTOUT("Example: \"MediaInfo --Output=Video;%AspectRatio% FileName\"");
+    STRINGOUT(String(__T("Usage: \" --Output=Video;%AspectRatio% FileName\"")).insert(8, Program_Name));
     TEXTOUT("");
-    TEXTOUT("Example: \"MediaInfo --Output=Video;file://Video.txt FileName\"");
+    STRINGOUT(String(__T("Usage: \" --Output=Video;file://Video.txt FileName\"")).insert(8, Program_Name));
     TEXTOUT("and Video.txt contains ");
     TEXTOUT("\"%DisplayAspectRatio%\"        for Video Aspect Ratio.");
     TEXTOUT("");
-    TEXTOUT("Example: \"MediaInfo --Output=file://Text.txt FileName\"");
+    STRINGOUT(String(__T("Usage: \" --Output=file://Text.txt FileName\"")).insert(8, Program_Name));
     TEXTOUT("and Text.txt contains");
     TEXTOUT("\"Video;%DisplayAspectRatio%\"  for Video Aspect Ratio.");
     TEXTOUT("\"Audio;%Format%\"              for Audio Format.");
@@ -155,15 +184,6 @@ int Help_Output()
     return MI_ERROR;
 }
 
-//---------------------------------------------------------------------------
-int Help_Security()
-{
-    TEXTOUT("Usage: \"MediaInfo [-Options...] FileName1 [Filename2...]\"");
-    TEXTOUT("\"MediaInfo --Help\" for displaying more information");
-
-    return MI_OK;
-}
-
 
 //---------------------------------------------------------------------------
 int Usage()
