@@ -51,15 +51,21 @@ public:
     void    Menu_View_Text                  ();
     void    Menu_View_HTML                  ();
     void    Menu_View_XML                   ();
+    void    Menu_View_JSON                  ();
     void    Menu_View_MPEG7                 ();
     void    Menu_View_PBCore                ();
     void    Menu_View_PBCore2               ();
     void    Menu_View_EBUCore_1_5           ();
     void    Menu_View_EBUCore_1_6           ();
+    void    Menu_View_EBUCore_1_8_ps        ();
+    void    Menu_View_EBUCore_1_8_sp        ();
+    void    Menu_View_EBUCore_1_8_ps_json   ();
+    void    Menu_View_EBUCore_1_8_sp_json   ();
     void    Menu_View_FIMS_1_1              ();
     void    Menu_View_FIMS_1_2              ();
     void    Menu_View_FIMS_1_3              ();
     void    Menu_View_reVTMD                ();
+    void    Menu_View_NISO_Z39_87           ();
     void    Menu_Option_Preferences_Inform  (const MediaInfoNameSpace::String &Inform);
     String  Menu_Option_Preferences_Option  (const MediaInfoNameSpace::String &Param, const MediaInfoNameSpace::String &Value);
     void    Menu_Debug_Complete             (bool Value);
@@ -69,11 +75,12 @@ public:
     void    Menu_Help_Info_Formats          ();
     void    Menu_Help_Info_Codecs           ();
     void    Menu_Help_Info_Parameters       ();
+    void    Menu_Help_Info_CanHandleUrls    ();
     void    Menu_Language                   (const MediaInfoNameSpace::String &Language);
 
     //Datas
     MediaInfoNameSpace::String &Inform_Get();
-    enum kind {Kind_Easy, Kind_Sheet, Kind_Tree, Kind_HTML, Kind_Text, Kind_XML, Kind_PBCore, Kind_PBCore2, Kind_reVTMD, Kind_MPEG7, Kind_EBUCore_1_4, Kind_FIMS_1_1, Kind_FIMS_1_2, Kind_FIMS_1_3};
+    enum kind {Kind_Easy, Kind_Sheet, Kind_Tree, Kind_HTML, Kind_Text, Kind_XML, Kind_JSON, Kind_PBCore, Kind_PBCore2, Kind_reVTMD, Kind_MPEG7, Kind_EBUCore_1_5, Kind_EBUCore_1_6, Kind_EBUCore_1_8_ps, Kind_EBUCore_1_8_sp, Kind_EBUCore_1_8_ps_json, Kind_EBUCore_1_8_sp_json, Kind_FIMS_1_1, Kind_FIMS_1_2, Kind_FIMS_1_3, Kind_NISO_Z39_87};
     kind    Kind_Get();
     MediaInfoNameSpace::String  Inform_Get          (size_t Pos, stream_t StreamKind, size_t StreamPos);
 
@@ -101,6 +108,7 @@ protected:
 
 private:
     Core (const Core&);
+	Core &operator =(const Core &a);
 
     friend class GUI_Main_Common_Core;
     friend class GUI_Main_Easy_Core;
