@@ -9,16 +9,19 @@
 #import <Cocoa/Cocoa.h>
 #import "oMediaInfoList.h"
 #import "HyperlinkButton.h"
+#import "TreeView.h"
+#import "CompareView.h"
 
 typedef enum { Kind_Text, Kind_XML, Kind_JSON, Kind_PBCore, Kind_PBCore2, Kind_reVTMD, Kind_MPEG7, Kind_EBUCore_1_5, Kind_EBUCore_1_6, Kind_EBUCore_1_8_ps, Kind_EBUCore_1_8_sp, Kind_EBUCore_1_8_ps_json, Kind_EBUCore_1_8_sp_json, Kind_FIMS_1_1, Kind_FIMS_1_2, Kind_FIMS_1_3, Kind_NISO_Z39_87} ViewMenu_Kind;
 
 @interface MyWindowController : NSWindowController {
 
+    IBOutlet NSPopUpButton *comboBox;
     IBOutlet NSArrayController *comboController;
     IBOutlet NSTabView *tabs;
+    IBOutlet NSBox *hline;
     IBOutlet NSSegmentedControl *tabSelector;
-    IBOutlet NSOutlineView *treeOutline;
-    IBOutlet NSTreeController *treeOutlineController;
+    IBOutlet TreeView *treeView;
     IBOutlet NSTextView *textField;
     IBOutlet NSMenu *otherViewsMenu;
     IBOutlet NSView *formatSelectionAccView;
@@ -28,13 +31,18 @@ typedef enum { Kind_Text, Kind_XML, Kind_JSON, Kind_PBCore, Kind_PBCore2, Kind_r
     IBOutlet HyperlinkButton *easyGeneralLinkButton;
     IBOutlet NSArrayController *easyStreamsController;
     IBOutlet NSTableView *easyTable;
+    IBOutlet CompareView *compareView;
 
     oMediaInfoList *mediaList;
     NSInteger selectedFileIndex;
 
     ViewMenu_Kind _lastTextKind;
     NSSavePanel *_exportSavePanel;
-}
+    BOOL fileSelectorIsHidden;
+    BOOL subscriptionEnabled;
+
+    NSMutableArray *observers;
+};
 
 //@property (assign) NSInteger selectedFileIndex;
 
@@ -43,6 +51,7 @@ typedef enum { Kind_Text, Kind_XML, Kind_JSON, Kind_PBCore, Kind_PBCore2, Kind_r
 -(IBAction)selectEasyTab:(id)sender;
 -(IBAction)selectTreeTab:(id)sender;
 -(IBAction)selectTextTab:(id)sender;
+-(IBAction)selectCompareTab:(id)sender;
 
 -(void)_selectViewOFKind:(ViewMenu_Kind)_kind;
 -(IBAction)selectViewXML:(id)sender;
@@ -68,6 +77,7 @@ typedef enum { Kind_Text, Kind_XML, Kind_JSON, Kind_PBCore, Kind_PBCore2, Kind_r
 -(NSInteger)selectedFileIndex;
 -(void)setSelectedFileIndex:(NSInteger)index;
 
+-(void)enableSubscription;
 -(void)processFiles:(NSArray *)URLs;
 -(void)showFileAtIndex:(NSUInteger)index;
 -(void)updateEasyTabWithFileAtIndex:(NSUInteger)index;
@@ -75,4 +85,8 @@ typedef enum { Kind_Text, Kind_XML, Kind_JSON, Kind_PBCore, Kind_PBCore2, Kind_r
 -(void)_updateTextTabWithContentOfAttributedTextAtIndex:(NSUInteger)index;
 -(void)_updateTextTabWithContentOfSimpleTextAtIndex:(NSUInteger)index;
 
+-(IBAction)selectNextTab:(id)sender;
+-(IBAction)selectPreviousTab:(id)sender;
+-(IBAction)closeFile:(id)sender;
+-(IBAction)closeAllFiles:(id)sender;
 @end
