@@ -6,10 +6,10 @@
 
 #include "columneditsheet.h"
 #include "sheet.h"
-#include <QtGui/QLineEdit>
-#include <QtGui/QSpinBox>
-#include <QtGui/QComboBox>
-#include <QtGui/QToolButton>
+#include <QLineEdit>
+#include <QSpinBox>
+#include <QComboBox>
+#include <QToolButton>
 #include "translate.h"
 
 #include <ZenLib/Ztring.h>
@@ -23,7 +23,7 @@ ColumnEditSheet::ColumnEditSheet(column c, int pos, int nb, Core* C, QWidget *pa
     QHBoxLayout(parent),
     pos(pos),
     C(C),
-    col(c),
+    col(c)
 {
     QLineEdit* lineedit = new QLineEdit(c.name);
     this->addWidget(lineedit);
@@ -43,6 +43,12 @@ ColumnEditSheet::ColumnEditSheet(column c, int pos, int nb, Core* C, QWidget *pa
     this->addWidget(stream);
     combobox = new QComboBox();
     combobox->addItem(c.key,c.key);
+
+#if defined(_WIN32) && defined(WINAPI_FAMILY) && (WINAPI_FAMILY==WINAPI_FAMILY_APP) // Workaround render bug
+    QString style = "QComboBox QAbstractItemView { border: 1px solid gray }";
+    combobox->setStyleSheet(style);
+#endif
+
     this->addWidget(combobox);
     up = new QToolButton();
     up->setArrowType(Qt::UpArrow);
