@@ -48,7 +48,7 @@ using namespace ZenLib;
 #define QString2wstring(_DATA) \
     Ztring().From_UTF8(_DATA.toUtf8())
 
-#define VERSION "18.12"
+#define VERSION "19.09"
 #if defined(_WIN32) && defined(WINAPI_FAMILY) && (WINAPI_FAMILY==WINAPI_FAMILY_APP) //UWP Application
 #include <QtPlatformHeaders/QWindowsWindowFunctions>
 #include <ZenLib/Os_Utils.h>
@@ -222,7 +222,7 @@ MainWindow::MainWindow(QStringList filesnames, int viewasked, QWidget *parent) :
 
     refreshDisplay();
 
-    if(filesnames.count()>1) {
+    if(filesnames.count()>0) {
         openFiles(filesnames);
     }
 
@@ -664,7 +664,7 @@ void MainWindow::refreshDisplay() {
         if(C->Count_Get()==1)
             setWindowTitle("MediaInfo - "+shortName(C,wstring2QString(C->Get(0, Stream_General, 0, __T("CompleteName")))));
         else
-            setWindowTitle(Tr("MediaInfo - %n files","window title",(int)C->Count_Get()));
+            setWindowTitle(QString("MediaInfo - %1 ").arg((int)C->Count_Get())+Tr("files","window title"));
 #endif
     }
     setCentralWidget(viewWidget);
