@@ -83,6 +83,12 @@ void TExportF::Name_Adapt()
         SaveDialog1->DefaultExt=__T("xml");
         SaveDialog1->Filter=__T("XML File|*.xml");
     }
+    else if (Export->ActivePage==Export_JSON)
+    {
+        FN.Extension_Set(__T("json"));
+        SaveDialog1->DefaultExt=__T("json");
+        SaveDialog1->Filter=__T("JSON File|*.json");
+    }
     else if (Export->ActivePage==Export_MPEG7)
     {
         FN.Extension_Set(__T("xml"));
@@ -161,6 +167,12 @@ void TExportF::Name_Adapt()
         SaveDialog1->DefaultExt=__T("xml");
         SaveDialog1->Filter=__T("XML File|*.xml");
     }
+    else if (Export->ActivePage==Export_NISO_Z39_87)
+    {
+        FN.Extension_Set(__T("xml"));
+        SaveDialog1->DefaultExt=__T("xml");
+        SaveDialog1->Filter=__T("XML File|*.xml");
+    }
     else if (Export->ActivePage==Export_Custom)
     {
         if (Prefs->Details[Prefs_Custom](Stream_Max+2, 1).size()>0 && Prefs->Details[Prefs_Custom](Stream_Max+2, 1)[0]==__T('<')) //test if HTML
@@ -197,6 +209,8 @@ int TExportF::Run(MediaInfoNameSpace::MediaInfoList &MI, ZenLib::Ztring DefaultF
         Export->ActivePage=Export_XML;
     else if (Info==__T("MIXML"))
         Export->ActivePage=Export_XML;
+    else if (Info==__T("JSON"))
+        Export->ActivePage=Export_JSON;
     else if (Info==__T("MPEG-7"))
         Export->ActivePage=Export_MPEG7;
     else if (Info==__T("PBCore_1.2"))
@@ -221,6 +235,8 @@ int TExportF::Run(MediaInfoNameSpace::MediaInfoList &MI, ZenLib::Ztring DefaultF
         Export->ActivePage=Export_FIMS_1_2;
     else if (Info==__T("FIMS_1.3"))
         Export->ActivePage=Export_FIMS_1_3;
+    else if (Info==__T("NISO_Z39.87"))
+        Export->ActivePage=Export_NISO_Z39_87;
     else if (Info==__T("reVTMD"))
         Export->ActivePage=Export_reVTMD;
 
@@ -462,6 +478,22 @@ void TExportF::Export_Run()
         }
         Text=ToExport->Inform().c_str();
     }
+    else if (Export->ActivePage==Export_JSON)
+    {
+        ToExport->Option_Static(__T("Inform"), __T("JSON"));
+        if (Export_JSON_SideCar->Checked)
+        {
+            for (size_t Pos=0; Pos<ToExport->Count_Get(); Pos++)
+            {
+                Text=ToExport->Inform(Pos).c_str();
+                File F;
+                F.Create(Ztring(ToExport->Get(Pos, Stream_General, 0, __T("CompleteName")).c_str())+__T(".mediainfo.json"));
+                F.Write(Text);
+            }
+            return;
+        }
+        Text=ToExport->Inform().c_str();
+    }
     else if (Export->ActivePage==Export_MPEG7)
     {
         ToExport->Option_Static(__T("Inform"), __T("MPEG-7"));
@@ -670,6 +702,22 @@ void TExportF::Export_Run()
         }
         Text=ToExport->Inform().c_str();
     }
+    else if (Export->ActivePage==Export_NISO_Z39_87)
+    {
+        ToExport->Option_Static(__T("Inform"), __T("NISO_Z39_87"));
+        if (Export_reVTMD_SideCar->Checked)
+        {
+            for (size_t Pos=0; Pos<ToExport->Count_Get(); Pos++)
+            {
+                Text=ToExport->Inform(Pos).c_str();
+                File F;
+                F.Create(Ztring(ToExport->Get(Pos, Stream_General, 0, __T("CompleteName")).c_str())+__T(".NISO_Z39_87.xml"));
+                F.Write(Text);
+            }
+            return;
+        }
+        Text=ToExport->Inform().c_str();
+    }
     else if (Export->ActivePage==Export_Custom)
     {
         ToExport->Option_Static(__T("Inform"), Prefs->Details[Prefs_Custom].Read());
@@ -717,6 +765,13 @@ void __fastcall TExportF::ExportChange(TObject *Sender)
         File_Append->Visible=false;
         Name_Choose->Visible=Export_XML_SideCar->Checked?false:true;;
     }
+    else if (Export->ActivePage==Export_JSON)
+    {
+        Export_JSON_SideCarClick(Sender);
+        File_Append->Checked=false;
+        File_Append->Visible=false;
+        Name_Choose->Visible=Export_JSON_SideCar->Checked?false:true;;
+    }
     else if (Export->ActivePage==Export_MPEG7)
     {
         Export_MPEG7_SideCarClick(Sender);
@@ -808,6 +863,13 @@ void __fastcall TExportF::ExportChange(TObject *Sender)
         File_Append->Visible=false;
         Name_Choose->Visible=Export_reVTMD_SideCar->Checked?false:true;;
     }
+    else if (Export->ActivePage==Export_NISO_Z39_87)
+    {
+        Export_NISO_Z39_87_SideCarClick(Sender);
+        File_Append->Checked=false;
+        File_Append->Visible=false;
+        Name_Choose->Visible=Export_NISO_Z39_87_SideCar->Checked?false:true;;
+    }
     else
     {
         File_Append->Visible=true;
@@ -866,6 +928,12 @@ void __fastcall TExportF::Export_XML_SideCarClick(TObject *Sender)
 }
 //---------------------------------------------------------------------------
 
+void __fastcall TExportF::Export_JSON_SideCarClick(TObject *Sender)
+{
+    Name_Choose->Visible=Export_JSON_SideCar->Checked?false:true;
+}
+//---------------------------------------------------------------------------
+
 void __fastcall TExportF::Export_MPEG7_SideCarClick(TObject *Sender)
 {
     Name_Choose->Visible=Export_MPEG7_SideCar->Checked?false:true;
@@ -942,6 +1010,13 @@ void __fastcall TExportF::Export_reVTMD_SideCarClick(TObject *Sender)
 {
     Name_Choose->Visible=Export_reVTMD_SideCar->Checked?false:true;
 }
+
+//---------------------------------------------------------------------------
+
+void __fastcall TExportF::Export_NISO_Z39_87_SideCarClick(TObject *Sender)
+{
+    Name_Choose->Visible=Export_NISO_Z39_87_SideCar->Checked?false:true;
+}
 //---------------------------------------------------------------------------
 
 void TExportF::GUI_Configure()
