@@ -214,6 +214,7 @@ void __fastcall TMainF::GUI_Configure()
     else if (Prefs->Config(__T("Output"))==__T("HTML")) {M_View_HTMLClick(NULL); M_View_HTML->Checked=true;}
     else if (Prefs->Config(__T("Output"))==__T("XML")) {M_View_XMLClick(NULL); M_View_XML->Checked=true;}
     else if (Prefs->Config(__T("Output"))==__T("MIXML")) {M_View_XMLClick(NULL); M_View_XML->Checked=true;}
+    else if (Prefs->Config(__T("Output"))==__T("JSON")) {M_View_JSONClick(NULL); M_View_JSON->Checked=true;}
     else if (Prefs->Config(__T("Output"))==__T("MPEG-7")) {M_View_MPEG7Click(NULL); M_View_MPEG7->Checked=true;}
     else if (Prefs->Config(__T("Output"))==__T("PBCore_1.2")) {M_View_PBCoreClick(NULL); M_View_PBCore->Checked=true;}
     else if (Prefs->Config(__T("Output"))==__T("PBCore_2.0")) {M_View_PBCore2Click(NULL); M_View_PBCore2->Checked=true;}
@@ -226,6 +227,7 @@ void __fastcall TMainF::GUI_Configure()
     else if (Prefs->Config(__T("Output"))==__T("FIMS_1.1")) {M_View_FIMS_1_1Click(NULL); M_View_FIMS_1_1->Checked=true;}
     else if (Prefs->Config(__T("Output"))==__T("FIMS_1.2")) {M_View_FIMS_1_2Click(NULL); M_View_FIMS_1_2->Checked=true;}
     else if (Prefs->Config(__T("Output"))==__T("FIMS_1.3")) {M_View_FIMS_1_3Click(NULL); M_View_FIMS_1_3->Checked=true;}
+    else if (Prefs->Config(__T("Output"))==__T("NISO_Z39.87")) {M_View_NISO_Z39_87Click(NULL); M_View_NISO_Z39_87->Checked=true;}
     else if (Prefs->Config(__T("Output"))==__T("reVTMD")) {M_View_reVTMDClick(NULL); M_View_reVTMD->Checked=true;}
     else if (Prefs->Config(__T("Output"))==__T("Custom")) {M_View_CustomClick(NULL); M_View_Custom->Checked=true;}
 
@@ -803,6 +805,8 @@ void __fastcall TMainF::Refresh(TTabSheet *Page)
     {
         if (M_View_XML->Checked)
             I->Option_Static(__T("Inform"), __T("MIXML"));
+        else if (M_View_JSON->Checked)
+            I->Option_Static(__T("Inform"), __T("JSON"));
         else if (M_View_MPEG7->Checked)
             I->Option_Static(__T("Inform"), __T("MPEG-7"));
         else if (M_View_PBCore->Checked)
@@ -829,6 +833,8 @@ void __fastcall TMainF::Refresh(TTabSheet *Page)
             I->Option_Static(__T("Inform"), __T("FIMS_1.3"));
         else if (M_View_reVTMD->Checked)
             I->Option_Static(__T("Inform"), __T("reVTMD"));
+        else if (M_View_NISO_Z39_87->Checked)
+            I->Option_Static(__T("Inform"), __T("NISO_Z39.87"));
         else
             I->Option_Static(__T("Inform"), Prefs->Details[Prefs_Custom].Read());
         Ztring S1=I->Inform();
@@ -1107,14 +1113,26 @@ void __fastcall TMainF::M_View_XMLClick(TObject *Sender)
     //Language
     I->Option_Static(__T("Language"), __T("raw"));
 
-    Prefs->Details[Prefs_Custom].Write(__T("MIXML"));
+    M_View_XML->Checked=true;
     ToolBar_View_XML->Checked=true;
     ChangePage(Page_Custom);
 }
+
+//---------------------------------------------------------------------------
+void __fastcall TMainF::M_View_JSONClick(TObject *Sender)
+{
+    //Language
+    I->Option_Static(__T("Language"), __T("raw"));
+
+    M_View_JSON->Checked=true;
+    ToolBar_View_JSON->Checked=true;
+    ChangePage(Page_Custom);
+}
+
 //---------------------------------------------------------------------------
 void __fastcall TMainF::M_View_MPEG7Click(TObject *Sender)
 {
-    Prefs->Details[Prefs_Custom].Write(__T("MPEG-7"));
+    M_View_MPEG7->Checked=true;
     ToolBar_View_MPEG7->Checked=true;
     ChangePage(Page_Custom);
 }
@@ -1122,15 +1140,23 @@ void __fastcall TMainF::M_View_MPEG7Click(TObject *Sender)
 //---------------------------------------------------------------------------
 void __fastcall TMainF::M_View_reVTMDClick(TObject *Sender)
 {
-    Prefs->Details[Prefs_Custom].Write(__T("reVTMD"));
+    M_View_reVTMD->Checked=true;
     ToolBar_View_reVTMD->Checked=true;
     ChangePage(Page_Custom);
 }
 
+//---------------------------------------------------------------------------
+void __fastcall TMainF::M_View_NISO_Z39_87Click(TObject *Sender)
+{
+    M_View_NISO_Z39_87->Checked=true;
+    ToolBar_View_NISO_Z39_87->Checked=true;
+    ChangePage(Page_Custom);
+}
+
 //---------------------------------------------------------------------------
 void __fastcall TMainF::M_View_PBCoreClick(TObject *Sender)
 {
-    Prefs->Details[Prefs_Custom].Write(__T("PBCore_1.2"));
+    M_View_PBCore->Checked=true;
     ToolBar_View_PBCore->Checked=true;
     ChangePage(Page_Custom);
 }
@@ -1138,7 +1164,7 @@ void __fastcall TMainF::M_View_PBCoreClick(TObject *Sender)
 //---------------------------------------------------------------------------
 void __fastcall TMainF::M_View_PBCore2Click(TObject *Sender)
 {
-    Prefs->Details[Prefs_Custom].Write(__T("PBCore_2.0"));
+    M_View_PBCore2->Checked=true;
     ToolBar_View_PBCore2->Checked=true;
     ChangePage(Page_Custom);
 }
@@ -1146,7 +1172,7 @@ void __fastcall TMainF::M_View_PBCore2Click(TObject *Sender)
 //---------------------------------------------------------------------------
 void __fastcall TMainF::M_View_EBUCore_1_5Click(TObject *Sender)
 {
-    Prefs->Details[Prefs_Custom].Write(__T("EBUCore_1.5"));
+    M_View_EBUCore_1_5->Checked=true;
     ToolBar_View_EBUCore_1_5->Checked=true;
     ChangePage(Page_Custom);
 }
@@ -1154,7 +1180,7 @@ void __fastcall TMainF::M_View_EBUCore_1_5Click(TObject *Sender)
 //---------------------------------------------------------------------------
 void __fastcall TMainF::M_View_EBUCore_1_6Click(TObject *Sender)
 {
-    Prefs->Details[Prefs_Custom].Write(__T("EBUCore_1.6"));
+    M_View_EBUCore_1_6->Checked=true;
     ToolBar_View_EBUCore_1_6->Checked=true;
     ChangePage(Page_Custom);
 }
@@ -1162,7 +1188,7 @@ void __fastcall TMainF::M_View_EBUCore_1_6Click(TObject *Sender)
 //---------------------------------------------------------------------------
 void __fastcall TMainF::M_View_EBUCore_1_8_psClick(TObject *Sender)
 {
-    Prefs->Details[Prefs_Custom].Write(__T("EBUCore_1.8_ps"));
+    M_View_EBUCore_1_8_ps->Checked=true;
     ToolBar_View_EBUCore_1_8_ps->Checked=true;
     ChangePage(Page_Custom);
 }
@@ -1170,7 +1196,7 @@ void __fastcall TMainF::M_View_EBUCore_1_8_psClick(TObject *Sender)
 //---------------------------------------------------------------------------
 void __fastcall TMainF::M_View_EBUCore_1_8_spClick(TObject *Sender)
 {
-    Prefs->Details[Prefs_Custom].Write(__T("EBUCore_1.8_sp"));
+    M_View_EBUCore_1_8_sp->Checked=true;
     ToolBar_View_EBUCore_1_8_sp->Checked=true;
     ChangePage(Page_Custom);
 }
@@ -1178,7 +1204,7 @@ void __fastcall TMainF::M_View_EBUCore_1_8_spClick(TObject *Sender)
 //---------------------------------------------------------------------------
 void __fastcall TMainF::M_View_EBUCore_1_8_ps_jsonClick(TObject *Sender)
 {
-    Prefs->Details[Prefs_Custom].Write(__T("EBUCore_1.8_ps_json"));
+    M_View_EBUCore_1_8_ps_json->Checked=true;
     ToolBar_View_EBUCore_1_8_ps_json->Checked=true;
     ChangePage(Page_Custom);
 }
@@ -1186,7 +1212,7 @@ void __fastcall TMainF::M_View_EBUCore_1_8_ps_jsonClick(TObject *Sender)
 //---------------------------------------------------------------------------
 void __fastcall TMainF::M_View_EBUCore_1_8_sp_jsonClick(TObject *Sender)
 {
-    Prefs->Details[Prefs_Custom].Write(__T("EBUCore_1.8_sp_json"));
+    M_View_EBUCore_1_8_sp_json->Checked=true;
     ToolBar_View_EBUCore_1_8_sp_json->Checked=true;
     ChangePage(Page_Custom);
 }
@@ -1194,7 +1220,7 @@ void __fastcall TMainF::M_View_EBUCore_1_8_sp_jsonClick(TObject *Sender)
 //---------------------------------------------------------------------------
 void __fastcall TMainF::M_View_FIMS_1_1Click(TObject *Sender)
 {
-    Prefs->Details[Prefs_Custom].Write(__T("FIMS_1.1"));
+    M_View_FIMS_1_1->Checked=true;
     ToolBar_View_FIMS_1_1->Checked=true;
     ChangePage(Page_Custom);
 }
@@ -1202,7 +1228,7 @@ void __fastcall TMainF::M_View_FIMS_1_1Click(TObject *Sender)
 //---------------------------------------------------------------------------
 void __fastcall TMainF::M_View_FIMS_1_2Click(TObject *Sender)
 {
-    Prefs->Details[Prefs_Custom].Write(__T("FIMS_1.2"));
+    M_View_FIMS_1_2->Checked=true;
     ToolBar_View_FIMS_1_2->Checked=true;
     ChangePage(Page_Custom);
 }
@@ -1210,7 +1236,7 @@ void __fastcall TMainF::M_View_FIMS_1_2Click(TObject *Sender)
 //---------------------------------------------------------------------------
 void __fastcall TMainF::M_View_FIMS_1_3Click(TObject *Sender)
 {
-    Prefs->Details[Prefs_Custom].Write(__T("FIMS_1.3"));
+    M_View_FIMS_1_3->Checked=true;
     ToolBar_View_FIMS_1_3->Checked=true;
     ChangePage(Page_Custom);
 }
