@@ -70,6 +70,7 @@ public:
     wxMenuItem* Menu_View_Text;
     wxMenuItem* Menu_View_HTML;
     wxMenuItem* Menu_View_XML;
+    wxMenuItem* Menu_View_JSON;
     wxMenuItem* Menu_View_MPEG7;
     wxMenuItem* Menu_View_PBCore_1_2;
     wxMenuItem* Menu_View_PBCore_2_0;
@@ -82,6 +83,7 @@ public:
     wxMenuItem* Menu_View_FIMS_1_1;
     wxMenuItem* Menu_View_FIMS_1_2;
     wxMenuItem* Menu_View_reVTMD;
+    wxMenuItem* Menu_View_NISO_Z39_87;
     wxMenu*     Menu_Debug;
     wxMenuItem* Menu_Debug_Complete;
     wxMenuItem* Menu_Debug_Details;
@@ -106,6 +108,7 @@ public:
     void OnMenu_View_Text               (wxCommandEvent &event);
     void OnMenu_View_HTML               (wxCommandEvent &event);
     void OnMenu_View_XML                (wxCommandEvent &event);
+    void OnMenu_View_JSON               (wxCommandEvent &event);
     void OnMenu_View_MPEG7              (wxCommandEvent &event);
     void OnMenu_View_PBCore_1_2         (wxCommandEvent &event);
     void OnMenu_View_PBCore_2_0         (wxCommandEvent &event);
@@ -118,6 +121,7 @@ public:
     void OnMenu_View_FIMS_1_1           (wxCommandEvent &event);
     void OnMenu_View_FIMS_1_2           (wxCommandEvent &event);
     void OnMenu_View_reVTMD             (wxCommandEvent &event);
+    void OnMenu_View_NISO_Z39_87        (wxCommandEvent &event);
     void OnMenu_Debug_Complete          (wxCommandEvent &event);
     void OnMenu_Debug_Details           (wxCommandEvent &event);
     void OnMenu_Debug_Demux_None        (wxCommandEvent &event);
